# Description: write the preface code for a shinyTex environment, given the options
# Arguments:
#   environ: the name of the environment (e.g., shinySidePanel)
#   option: a single option, in string form, appropriate for the environment 
# Value: a string vector with Shiny ui code
#
prefaceCode = function(environ, option, lineNumOffset, globalInfoEnv) {
  if (environ == "shinySidePanel") {
    return(c('sidebarLayout(', 'sidebarPanel('))
  } else if (environ == "shinyMainPanel") {
    return('mainPanel(')
  } else if (environ == "shinyColumns") {
    return(paste0('fluidRow(column(width=', option, ','))
  } else if (environ == "shinyNextColumn") {
    return(paste0('column(width=', option, ','))
  } else if (environ == "shinyLastColumn") {
    return(paste0('column(width=', option, ','))
  } else if (environ == "shinyNavbarMenu") {
    return(c('navbarMenu(', paste0('  title=', option, ',')))
  } else if (environ == "shinyEnumerate") {
    return('HTML("<ol>"),')
  } else if (environ == "shinyItemize") {
    return('HTML("<ul>"),')
  } else if (environ == "shinyConditionalPanel") {
    option = parseCommand(paste0("\foo{",option,"}"))$options
    option = parseOptions(environ, option, required=c("inputId","value"), requiredTypes=c("c","c"),
                         optional=NULL, optionalTypes=NULL, lineNumOffset=lineNumOffset)
    logical = option$value %in% c("TRUE", "FALSE") # ??????!!!!!! check control type instead ?????? !!!!
    if (logical) {
      condition = paste0('\"input.', option$inputId, ' == ', tolower(option$value), '\"')      
    } else {
      condition = paste0('\"input.', option$inputId, ' == \'', option$value, '\'\"')      
    }
    conditionalPanels = getGlobal("conditionalPanels", globalInfoEnv)
    if (is.null(conditionalPanels)) {
      conditionalPanels = data.frame(lineNum=lineNumOffset, inputId=I(option$inputId), 
                                     condition=I(option$value))
    } else {
      conditionalPanels = rbind(conditionalPanels, 
                                data.frame(lineNum=lineNumOffset, inputId=I(option$inputId), 
                                           condition=I(option$value)))
    }
    assign("conditionalPanels", conditionalPanels, envir=globalInfoEnv)
    return(paste0('conditionalPanel(', condition, ','))
  } else stop("preface code does not handle ", environ)
}
